@@ -37,10 +37,10 @@ It works whether the optimization is ongoing or finished. The plot will be produ
 directory provided via argument -opti_dir.
 
 Top row displays bonded terms score (global and breakdown) together with radius of gyration
-(Rg) and solvent accessible surface area (SASA) estimation. We call these estimations because
+(Rg) and solvent accessible surface area (SASA) estimations. We call these estimations because
 they are calculated on short simulations used during optimization (time depends on parameters
-used for optimization), therefore you should always run a long simulation at the end of the
-optimizaton process, from which you can calculate the real Rg and SASA values for your model.
+used for optimization), therefore one should always run a long simulation at the end of the
+optimizaton process, from which one can calculate the real Rg and SASA values for your model.
 
 Other rows display bond, angle and dihedral parameters tested together with their independant
 score (distance from the AA distributions using EMD/Wasserstein). This allows to diagnose
@@ -84,7 +84,6 @@ extended conformations).
 	print()
 
 	# parameters
-	create_video = False
 	read_offset = 15 # nb of trailing fields that have static lengths in the recap file (i.e. NOT dependent on number of bonds, angles, etc.)
 	min_nb_cols = 9 # to be sure we have enough columns for opti process plots, even if number of bonds/angles/dihedrals is less than this
 
@@ -327,7 +326,7 @@ extended conformations).
 	# all evaluations scores and stats
 	x_evals = list(range(1, len(all_fit_score_total)+1))[:nb_evals]
 
-	# ax[0][0].set_title("Total fitness scores")
+	ax[0][0].set_title("All evaluations scores")
 	ax[0][0].grid(zorder=0.5)
 	ax[0][0].plot(x_evals, all_fit_score_total, color=color_scores)
 	if display_sim_crashes:
@@ -339,7 +338,7 @@ extended conformations).
 	ax[0][0].plot(id_best_all+1, all_fit_score_total[id_best_all], marker='D', color='white', markerfacecolor='gold', markersize=10, markeredgewidth=1.5, markeredgecolor='black', label='Selected model')
 	ax[0][0].legend(loc='upper right')
 
-	ax[0][1].set_title("All evaluation scores")
+	ax[0][1].set_title("All adaptives scores")
 	ax[0][1].grid(zorder=0.5)
 	ax[0][1].plot(x_evals, all_eval_scores, color=color_scores)
 	if display_sim_crashes:
@@ -350,7 +349,7 @@ extended conformations).
 	ax[0][1].plot(id_best_all+1, all_eval_scores[id_best_all], marker='D', color='white', markerfacecolor='gold', markersize=10, markeredgewidth=1.5, markeredgecolor='black', label='Selected model')
 	# ax[0][1].legend(loc='upper right')
 
-	ax[0][2].set_title("Cstrs & bonds fitness scores")
+	ax[0][2].set_title("Cstrs & bonds scores")
 	ax[0][2].grid(zorder=0.5)
 	ax[0][2].plot(x_evals, all_fit_score_constraints_bonds, color=color_scores)
 	if display_sim_crashes:
@@ -361,7 +360,7 @@ extended conformations).
 	ax[0][2].plot(id_best_all+1, all_fit_score_constraints_bonds[id_best_all], marker='D', color='white', markerfacecolor='gold', markersize=10, markeredgewidth=1.5, markeredgecolor='black', label='Selected model')
 	# ax[0][2].legend(loc='upper right')
 
-	ax[0][3].set_title("Angles fitness scores")
+	ax[0][3].set_title("Angles scores")
 	ax[0][3].grid(zorder=0.5)
 	ax[0][3].plot(x_evals, all_fit_score_angles, color=color_scores)
 	if display_sim_crashes:
@@ -372,7 +371,7 @@ extended conformations).
 	ax[0][3].plot(id_best_all+1, all_fit_score_angles[id_best_all], marker='D', color='white', markerfacecolor='gold', markersize=10, markeredgewidth=1.5, markeredgecolor='black', label='Selected model')
 	# ax[0][3].legend(loc='upper right')
 
-	ax[0][4].set_title("Dihedrals fitness scores")
+	ax[0][4].set_title("Dihedrals scores")
 	ax[0][4].grid(zorder=0.5)
 	ax[0][4].plot(x_evals, all_fit_score_dihedrals, color=color_scores)
 	if display_sim_crashes:
@@ -383,12 +382,12 @@ extended conformations).
 	ax[0][4].plot(id_best_all+1, all_fit_score_dihedrals[id_best_all], marker='D', color='white', markerfacecolor='gold', markersize=10, markeredgewidth=1.5, markeredgecolor='black', label='Selected model')
 	# ax[0][4].legend(loc='upper right')
 
-	# ax[0][5].set_title("Radius of gyration")
+	ax[0][5].set_title("Radius of gyration")
 	ax[0][5].grid(zorder=0.5)
 	ax[0][5].plot(x_evals, all_gyr_aa_mapped, color=config.atom_color, label='AA-mapped', lw=2.5)
 	if plot_control_std:
 		ax[0][5].fill_between(x_evals, list(all_gyr_aa_mapped-all_gyr_aa_mapped_std), list(all_gyr_aa_mapped+all_gyr_aa_mapped_std), color=config.atom_color, alpha=0.1)
-	ax[0][5].plot(x_evals, all_gyr_cg, color=config.cg_color, label='CG')
+	ax[0][5].plot(x_evals, all_gyr_cg, color=config.cg_color, label='CG estimation')
 	if plot_control_std:
 		ax[0][5].fill_between(x_evals, list(all_gyr_cg-all_gyr_cg_std), list(all_gyr_cg+all_gyr_cg_std), color=config.cg_color, alpha=0.2)
 	if display_sim_crashes:
@@ -402,12 +401,12 @@ extended conformations).
 	ax[0][5].plot(id_best_all+1, all_gyr_cg[id_best_all], marker='D', color='white', markerfacecolor='gold', markersize=10, markeredgewidth=1.5, markeredgecolor='black', label='') #label='Selected model')
 	ax[0][5].legend(loc='lower right')
 
-	# ax[0][6].set_title("SASA")
+	ax[0][6].set_title("SASA")
 	ax[0][6].grid(zorder=0.5)
 	ax[0][6].plot(x_evals, all_sasa_aa_mapped, color=config.atom_color, label='AA-mapped', lw=2.5)
 	if plot_control_std:
 		ax[0][6].fill_between(x_evals, list(all_sasa_aa_mapped-all_sasa_aa_mapped_std), list(all_sasa_aa_mapped+all_sasa_aa_mapped_std), color=config.atom_color, alpha=0.1)
-	ax[0][6].plot(x_evals, all_sasa_cg, color=config.cg_color, label='CG')
+	ax[0][6].plot(x_evals, all_sasa_cg, color=config.cg_color, label='CG estimation')
 	if plot_control_std:
 		ax[0][6].fill_between(x_evals, list(all_sasa_cg-all_sasa_cg_std), list(all_sasa_cg+all_sasa_cg_std), color=config.cg_color, alpha=0.2)
 	if display_sim_crashes:
@@ -658,173 +657,3 @@ extended conformations).
 
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-	# # if we also want to create a video
-	# plots_dir = 'all_opti_moves_plots' # to plot optimization snapshots at each new iteration, so that we can make a video with these frames
-
-	# if create_video:
-
-	# 	# create directory for all plots, if it does not exist
-	# 	if not os.path.isdir(plots_dir):
-	# 		os.system('mkdir '+plots_dir)
-
-	# 	nb_plots = 0
-
-	# 	# this is just a copy of the previous block but with iteration over all the evaluation scores
-	# 	for k in range(10, len(all_eval_scores)): # nb of points to use
-
-	# 		nb_plots += 1
-
-	# 		# linear regression on all evaluation scores, the 2 last third and the very last third of them, to visually check for continued optimization
-	# 		slope, intercept = polyfit(list(range(len(all_eval_scores[:k]))), np.array(all_eval_scores[:k]), 1)
-	# 		try:
-	# 			slope_conti, intercept_conti = polyfit(list(range(int(len(all_eval_scores[:k])*1/3), len(all_eval_scores[:k]))), np.array(all_eval_scores[:k][int(len(all_eval_scores[:k])*1/3):]), 1)
-	# 		except:
-	# 			pass
-	# 		try:
-	# 			slope_conti2, intercept_conti2 = polyfit(list(range(int(len(all_eval_scores[:k])*2/3), len(all_eval_scores[:k]))), np.array(all_eval_scores[:k][int(len(all_eval_scores[:k])*2/3):]), 1) 
-	# 		except:
-	# 			pass
-
-	# 		larger_group = max(nb_constraints, nb_bonds, nb_angles, nb_dihedrals)
-	# 		nrow, nrows, ncols = 0, 5, larger_group
-	# 		nrows -= sum([nb_constraints == 0, nb_bonds == 0, nb_angles == 0, nb_dihedrals == 0])
-
-	# 		fig, ax = plt.subplots(nrows=nrows, ncols=ncols, figsize=(ncols*4, nrows*3))
-
-	# 		# all evaluations scores and stats
-	# 		ax[0][0].set_title("All evaluation scores")
-	# 		ax[0][0].plot(x_evals, all_eval_scores[:k])
-	# 		ax[0][0].plot(slope*np.array(range(len(all_eval_scores[:k])))+intercept, color='darkgrey', linestyle='--')
-	# 		try:
-	# 			ax[0][0].plot(x_evals, list(range(int(len(all_eval_scores[:k])*1/3), len(all_eval_scores[:k]))), slope_conti*np.array(range(int(len(all_eval_scores[:k])*1/3), len(all_eval_scores[:k])))+intercept_conti, color='grey', linestyle='--')
-	# 		except:
-	# 			pass
-	# 		try:
-	# 			ax[0][0].plot(x_evals, list(range(int(len(all_eval_scores[:k])*2/3), len(all_eval_scores[:k]))), slope_conti2*np.array(range(int(len(all_eval_scores[:k])*2/3), len(all_eval_scores[:k])))+intercept_conti2, color='black', linestyle='--')
-	# 		except:
-	# 			pass
-	# 		ax[0][0].grid(zorder=0.5)
-
-	# 		ax[0][1].set_title("All evaluation times (min)")
-	# 		ax[0][1].plot(x_evals, all_eval_times[:k])
-	# 		ax[0][1].grid(zorder=0.5)
-
-	# 		ax[0][2].set_title("Total time (hours)")
-	# 		ax[0][2].plot(x_evals, all_total_times[:k])
-	# 		ax[0][2].grid(zorder=0.5)
-
-	# 		for i in range(3, ncols):
-	# 			ax[0][i].set_visible(False)
-
-	# 		plt_sidespace = 0.05 # ylim bottom and top margin as a percentage of y range of data
-
-	# 		# constraints
-	# 		if nb_constraints != 0:
-	# 			nrow += 1
-	# 			for i in range(ncols):
-	# 				if i < nb_constraints:
-	# 					ax[nrow][i].set_title('Constraint '+str(i+1))
-	# 					ax[nrow][i].plot(x_evals, parameters_vals['constraints']['values'][i][:k])
-	# 					ax[nrow][i].grid(zorder=0.5)
-	# 					# ax[nrow][i].set_ylim(bottom=domains_ranges['constraints'][i][0]-(domains_ranges['constraints'][i][1]-domains_ranges['constraints'][i][0])*plt_sidespace, top=domains_ranges['constraints'][i][1]+(domains_ranges['constraints'][i][1]-domains_ranges['constraints'][i][0])*plt_sidespace)
-	# 				else:
-	# 					ax[nrow][i].set_visible(False)
-
-	# 		# bonds
-	# 		if nb_bonds != 0:
-	# 			nrow += 1
-	# 			for i in range(ncols):
-	# 				if i < nb_bonds:
-	# 					ax[nrow][i].set_title('Bond '+str(i+1))
-	# 					ax[nrow][i].grid(zorder=0.5)
-	# 					color = 'tab:blue'
-	# 					ax[nrow][i].plot(x_evals, parameters_vals['bonds']['values'][i][:k], color=color)
-	# 					ax[nrow][i].tick_params(axis='y', labelcolor=color)
-	# 					# ax[nrow][i].set_ylim(bottom=domains_ranges['bonds'][i][0]-(domains_ranges['bonds'][i][1]-domains_ranges['bonds'][i][0])*plt_sidespace, top=domains_ranges['bonds'][i][1]+(domains_ranges['bonds'][i][1]-domains_ranges['bonds'][i][0])*plt_sidespace)
-	# 					ax2 = ax[nrow][i].twinx()
-	# 					color = 'tab:red'
-	# 					ax2.plot(x_evals, parameters_vals['bonds']['force_ctr'][i][:k], color=color)
-	# 					ax2.set_ylim(bottom=bonds_fct_domain[0]-(bonds_fct_domain[1]-bonds_fct_domain[0])*plt_sidespace, top=bonds_fct_domain[1]+(bonds_fct_domain[1]-bonds_fct_domain[0])*plt_sidespace)
-	# 					if i == nb_bonds-1:
-	# 						ax2.tick_params(axis='y', labelcolor=color)
-	# 					else:
-	# 						ax2.yaxis.set_ticklabels([])
-	# 				else:
-	# 					ax[nrow][i].set_visible(False)
-
-	# 		# angles
-	# 		if nb_angles != 0:
-	# 			nrow += 1
-	# 			for i in range(ncols):
-	# 				if i < nb_angles:
-	# 					ax[nrow][i].set_title('Angle '+str(i+1))
-	# 					ax[nrow][i].grid(zorder=0.5)
-	# 					color = 'tab:blue'
-	# 					ax[nrow][i].plot(x_evals, parameters_vals['angles']['values'][i][:k], color=color)
-	# 					ax[nrow][i].tick_params(axis='y', labelcolor=color)
-	# 					# ax[nrow][i].set_ylim(bottom=domains_ranges['angles'][i][0]-(domains_ranges['angles'][i][1]-domains_ranges['angles'][i][0])*plt_sidespace, top=domains_ranges['angles'][i][1]+(domains_ranges['angles'][i][1]-domains_ranges['angles'][i][0])*plt_sidespace)
-	# 					ax2 = ax[nrow][i].twinx()
-	# 					color = 'tab:red'
-	# 					ax2.plot(x_evals, parameters_vals['angles']['force_ctr'][i][:k], color=color)
-	# 					ax2.set_ylim(bottom=angles_fct_domain[0]-(angles_fct_domain[1]-angles_fct_domain[0])*plt_sidespace, top=angles_fct_domain[1]+(angles_fct_domain[1]-angles_fct_domain[0])*plt_sidespace)
-	# 					if i == nb_angles-1:
-	# 						ax2.tick_params(axis='y', labelcolor=color)
-	# 					else:
-	# 						ax2.yaxis.set_ticklabels([])
-	# 				else:
-	# 					ax[nrow][i].set_visible(False)
-
-	# 		# dihedrals
-	# 		if nb_dihedrals != 0:
-	# 			nrow += 1
-	# 			for i in range(ncols):
-	# 				if i < nb_dihedrals:
-	# 					ax[nrow][i].set_title('Dihedral '+str(i+1))
-	# 					ax[nrow][i].grid(zorder=0.5)
-	# 					color = 'tab:blue'
-	# 					ax[nrow][i].plot(x_evals, parameters_vals['dihedrals']['values'][i][:k], color=color)
-	# 					ax[nrow][i].tick_params(axis='y', labelcolor=color)
-	# 					# ax[nrow][i].set_ylim(bottom=domains_ranges['dihedrals'][i][0]-(domains_ranges['dihedrals'][i][1]-domains_ranges['dihedrals'][i][0])*plt_sidespace, top=domains_ranges['dihedrals'][i][1]+(domains_ranges['dihedrals'][i][1]-domains_ranges['dihedrals'][i][0])*plt_sidespace)
-	# 					ax2 = ax[nrow][i].twinx()
-	# 					color = 'tab:red'
-	# 					ax2.plot(x_evals, parameters_vals['dihedrals']['force_ctr'][i][:k], color=color)
-	# 					ax2.set_ylim(bottom=dihedrals_fct_domain[0]-(dihedrals_fct_domain[1]-dihedrals_fct_domain[0])*plt_sidespace, top=dihedrals_fct_domain[1]+(dihedrals_fct_domain[1]-dihedrals_fct_domain[0])*plt_sidespace)
-	# 					if i == nb_dihedrals-1:
-	# 						ax2.tick_params(axis='y', labelcolor=color)
-	# 					else:
-	# 						ax2.yaxis.set_ticklabels([])
-	# 				else:
-	# 					ax[nrow][i].set_visible(False)
-
-	# 		plt.tight_layout()
-	# 		nb_plots_formatted = "%05d" %nb_plots 
-	# 		plt.savefig(plots_dir+'/analyze_optimization_'+nb_plots_formatted+'.png')
-	# 		plt.close()
-	# 		print('Wrote results to file: '+plots_dir+'/analyze_optimization_'+nb_plots_formatted+'.png')
-
-	# 	print('Created all plots for video, now creating video')
-	# 	print()
-
-	# 	ffmpeg_cmd = 'ffmpeg -framerate 20 -i '+plots_dir+'/analyze_optimization_%05d.png -c:v libx264 -preset fast -crf 24 '+plots_dir+'/analyze_optimization.mp4 -y'
-	# 	os.system(ffmpeg_cmd)
-
-	# 	print()
-	# 	print('Created video file: '+plots_dir+'/analyze_optimization.mp4')
-
-
-
