@@ -1,5 +1,5 @@
 # general stuff
-module_version = '1.0'
+module_version = '1.0.4'
 github_url = 'http://github.com/GMPavanLab/SwarmCG'
 gmx_path = 'gmx'
 
@@ -107,14 +107,14 @@ help_max_fct_dihedrals_without_mult = 'Max. force ct. for dihedrals function 2 (
 # optimization output filenames
 input_sim_files_dirname = '.internal/input_CG_simulation_files'
 iteration_sim_files_dirname = 'CG_sim_files' # basename to be appended to with _NN
-best_fitted_model_dirname = 'Best_fitted_model'
-distrib_plots_all_evals_dirname = 'Distributions_plots_all_evaluations'
-log_files_all_evals_dirname = 'CG_sim_log_files_all_evaluations'
-sim_files_all_evals_dirname = 'CG_sim_all_files_all_evaluations'
+best_fitted_model_dirname = 'optimized_CG_model'
+distrib_plots_all_evals_dirname = 'all_evals_distributions'
+log_files_all_evals_dirname = 'all_evals_logs'
+sim_files_all_evals_dirname = 'all_evals_all_sim_files'
 opti_perf_recap_file = '.internal/opti_recap_evals_perfs_and_params.csv'
 opti_pairwise_distances_file = '.internal/opti_recap_evals_pairwise_distribs_diffs.csv'
-ref_distrib_plots = 'Reference_model_AA-mapped_groups_distributions.png'
-best_distrib_plots = 'Best_fitted_model_AA-mapped_vs_CG_groups_distributions.png'
+ref_distrib_plots = 'reference_AA_distributions.png'
+best_distrib_plots = 'optimized_CG_model_distributions.png'
 
 # stdout display formatting
 sep = '----------------------------------------------------------------------'
